Unreleased changes
------------------
Version 0
---------

0.2.0 / 2021-03-04
~~~~~~~~~~~~~~~~~~
* Add km3services

0.1.0 / 2021-03-02
~~~~~~~~~~~~~~~~~~
* Removes template artifacts
* Project generated using the cookiecutter template from
  https://git.km3net.de/templates/python-project
